@@ -30,7 +30,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kstandardaction.h>
 
 #include <kwinglutils.h>
+#ifdef KWIN_HAVE_XRENDER_COMPOSITING
 #include <kwinxrenderutils.h>
+#endif
 
 namespace KWin
 {
@@ -66,6 +68,10 @@ MagnifierEffect::~MagnifierEffect()
     delete m_fbo;
     delete m_texture;
     delete m_pixmap;
+    // Save the zoom value.
+    KConfigGroup conf = EffectsHandler::effectConfig("Magnifier");
+    conf.writeEntry("InitialZoom", target_zoom);
+    conf.sync();
 }
 
 bool MagnifierEffect::supported()
@@ -81,6 +87,10 @@ void MagnifierEffect::reconfigure(ReconfigureFlags)
     width = conf.readEntry("Width", 200);
     height = conf.readEntry("Height", 200);
     magnifier_size = QSize(width, height);
+    // Load the saved zoom value.
+    target_zoom = conf.readEntry("InitialZoom", target_zoom);
+    if (target_zoom != zoom)
+        toggle();
 }
 
 void MagnifierEffect::prePaintScreen(ScreenPrePaintData& data, int time)
@@ -166,6 +176,7 @@ void MagnifierEffect::paintScreen(int mask, QRegion region, ScreenPaintData& dat
             }
         }
         if (effects->compositingType() == XRenderCompositing) {
+#ifdef KWIN_HAVE_XRENDER_COMPOSITING
             if (!m_pixmap || m_pixmap->size() != srcArea.size()) {
                 delete m_pixmap;
                 m_pixmap = new QPixmap(srcArea.size());
@@ -199,6 +210,7 @@ void MagnifierEffect::paintScreen(int mask, QRegion region, ScreenPaintData& dat
                                           { area.x(), area.y(), FRAME_WIDTH, area.height()-FRAME_WIDTH} };
             XRenderColor c = preMultiply(QColor(0,0,0,255));
             XRenderFillRectangles(display(), PictOpSrc, effects->xrenderBufferPicture(), &c, rects, 4);
+#endif
         }
     }
 }
@@ -256,8 +268,10 @@ void MagnifierEffect::zoomOut()
 
 void MagnifierEffect::toggle()
 {
-    if (target_zoom == 1.0) {
-        target_zoom = 2;
+    if (zoom == 1.0) {
+        if (target_zoom == 1.0) {
+            target_zoom = 2;
+        }
         if (!polling) {
             polling = true;
             effects->startMousePolling();
