@@ -766,8 +766,7 @@ void Workspace::performWindowOperation(Client* c, Options::WindowOperation op)
     case Options::NoOp:
         break;
     case Options::RemoveTabFromGroupOp:
-        if (c->untab())
-        if (options->focusPolicyIsReasonable())
+        if (c->untab(c->geometry().translated(cascadeOffset(c))) && options->focusPolicyIsReasonable())
              takeActivity(c, ActivityFocus | ActivityRaise, true);
         break;
     case Options::ActivateNextTabOp:
@@ -1052,6 +1051,13 @@ QStringList Workspace::listOfEffects() const
     return listModules;
 }
 
+QString Workspace::supportInformationForEffect(const QString& name) const
+{
+    if (effects)
+        return static_cast<EffectsHandlerImpl*>(effects)->supportInformation(name);
+    return QString();
+}
+
 void Workspace::slotActivateAttentionWindow()
 {
     if (attention_chain.count() > 0)
@@ -1417,7 +1423,7 @@ void Workspace::slotActivatePrevTab()
 void Workspace::slotUntab()
 {
     if (active_client)
-        active_client->untab();
+        active_client->untab(active_client->geometry().translated(cascadeOffset(active_client)));
 }
 
 /*!
