@@ -301,6 +301,8 @@ public:
      */
     int desktopToLeft(int id = 0, bool wrap = true) const;
 
+    QPoint cascadeOffset(const Client *c) const;
+
 private:
     int desktopCount_;
     QSize desktopGridSize_;
@@ -392,6 +394,7 @@ public:
     void toggleEffect(const QString& name);
     void reconfigureEffect(const QString& name);
     void unloadEffect(const QString& name);
+    QString supportInformationForEffect(const QString& name) const;
     void updateCompositeBlocking(Client* c = NULL);
 
     QStringList loadedEffects() const;
